Each subdirectory stores some type of dataset, that can be used in ntrfc-modules
Some data is shown in the examples Jupyter-Notebooks, other datasets might be used for testing purposes.

Each subdirectory has it's own README and will tell something about the data.
If anything is missing, let me know and write an issue.
